==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.md <==
# AwsIoTThingFreeRtosDevice


```text
aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')
```



| Illustration | AwsIoTThingFreeRtosDevice | AwsIoTThingFreeRtosDeviceCard | AwsIoTThingFreeRtosDeviceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.png) | ![illustration for AwsIoTThingFreeRtosDevice](../../../aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.Local.png) | ![illustration for AwsIoTThingFreeRtosDeviceCard](../../../aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDeviceCard.Local.png) | ![illustration for AwsIoTThingFreeRtosDeviceGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDeviceGroup.Local.png) |




## AwsIoTThingFreeRtosDevice

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDevice
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDevice('AwsIoTThingFreeRtosDevice', 'Aws Io T Thing Free Rtos Device', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDevice
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDevice('AwsIoTThingFreeRtosDevice', 'Aws Io T Thing Free Rtos Device', 'an optional tech label')
@enduml
```

## AwsIoTThingFreeRtosDeviceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceCard('AwsIoTThingFreeRtosDeviceCard', 'Aws Io T Thing Free Rtos Device Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceCard('AwsIoTThingFreeRtosDeviceCard', 'Aws Io T Thing Free Rtos Device Card', 'an optional description')
@enduml
```

## AwsIoTThingFreeRtosDeviceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceGroup('AwsIoTThingFreeRtosDeviceGroup', 'Aws Io T Thing Free Rtos Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceGroup('AwsIoTThingFreeRtosDeviceGroup', 'Aws Io T Thing Free Rtos Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.md <==
# AwsIoTThingFreeRtosDevice


```text
aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')
```



| Illustration | AwsIoTThingFreeRtosDevice | AwsIoTThingFreeRtosDeviceCard | AwsIoTThingFreeRtosDeviceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.png) | ![illustration for AwsIoTThingFreeRtosDevice](../../../aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice.Local.png) | ![illustration for AwsIoTThingFreeRtosDeviceCard](../../../aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDeviceCard.Local.png) | ![illustration for AwsIoTThingFreeRtosDeviceGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDeviceGroup.Local.png) |




## AwsIoTThingFreeRtosDevice

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDevice
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDevice('AwsIoTThingFreeRtosDevice', 'Aws Io T Thing Free Rtos Device', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDevice
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDevice('AwsIoTThingFreeRtosDevice', 'Aws Io T Thing Free Rtos Device', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTThingFreeRtosDeviceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceCard
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceCard('AwsIoTThingFreeRtosDeviceCard', 'Aws Io T Thing Free Rtos Device Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceCard
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceCard('AwsIoTThingFreeRtosDeviceCard', 'Aws Io T Thing Free Rtos Device Card', 'an optional description')
@enduml
```

## AwsIoTThingFreeRtosDeviceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceGroup
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceGroup('AwsIoTThingFreeRtosDeviceGroup', 'Aws Io T Thing Free Rtos Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingFreeRtosDeviceGroup
include('aws-q1-2022/Resource/LoT/AwsIoTThingFreeRtosDevice')

' renders the element
AwsIoTThingFreeRtosDeviceGroup('AwsIoTThingFreeRtosDeviceGroup', 'Aws Io T Thing Free Rtos Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
